Computes the geometric heart-rate-variability measures defined by the Task Force (1996) from a series of NN (normal-to-normal) intervals: the HRV triangular index and the triangular interpolation of the NN interval histogram (TINN).
Value
A list with:
- HRV_triangular_index
Total number of NN intervals divided by the height (modal count) of the NN histogram.
- TINN
Baseline width, in milliseconds, of the triangle that best approximates the NN histogram in a least-squares sense.
References
Task Force of the ESC and NASPE (1996). Heart rate variability: standards of measurement. Circulation, 93(5), 1043-1065.