Detect ventilatory thresholds from incremental exercise data
Source:R/resp.R
ventilatoryThreshold.RdVT1 is estimated by V-slope breakpoint regression of VCO2 on VO2. VT2 is estimated above VT1 from the breakpoint of VE on VCO2.
Usage
ventilatoryThreshold(
vo2,
vco2 = NULL,
ve = NULL,
time = NULL,
average_n = 1L,
min_segment = 3L
)Arguments
- vo2
Numeric VO2 vector, or a data frame containing
vo2,vco2, andve.- vco2, ve
Numeric vectors matching
vo2when it is not a data frame.- time
Optional time vector. For data-frame input, an existing
timecolumn is used unless this argument is supplied.- average_n
Positive integer number of ordered samples per block mean.
- min_segment
Minimum number of observations fitted on each side of a breakpoint.
References
Beaver WL, Wasserman K, Whipp BJ (1986). A new method for detecting anaerobic threshold by gas exchange. Journal of Applied Physiology, 60:2020-2027. doi:10.1152/jappl.1986.60.6.2020